@@ -9,6 +9,7 @@ from insightconnect_plugin_runtime.exceptions import (
     ServerException,
     LoggedException,
     ConnectionTestException,
+    PluginException,
 )
 from insightconnect_plugin_runtime.api.schemas import (
     PluginInfoSchema,
@@ -286,6 +287,23 @@ class Endpoints:
                 action_list.append(action)
             return jsonify(action_list)
 
+        @v1.route("/definitions/actions")
+        def definitions_all_actions():
+            """Return definitions for all actions
+            ---
+            get:
+              summary: Get list of plugin actions with associated input schemas
+              description: Get InsightConnect plugin all actions with associated input schemas
+              responses:
+                200:
+                  description: InsightConnect Plugin actions with input schemas list to be returned
+                  schema:
+                    type: object
+            """
+
+            response = self._create_action_definitions_payload()
+            return jsonify(response)
+
         @v1.route("/tasks")
         def tasks():
             """Plugin tasks list endpoint.
@@ -309,22 +327,22 @@ class Endpoints:
         @v1.route("/actions/<string:name>")
         def action_details(name):
             """Get action details endpoint.
-             ---
-             get:
-               summary: Retrieve action details
-               description: Retrieve action details
-               parameters:
-                 - in: path
-                   name: name
-                   description: Name of the action
-                   type: string
-               responses:
-                 200:
-                   description: Action details to be returned
-                   schema: ActionTriggerDetailsSchema
-                 400:
-                   description: Bad request
-             """
+            ---
+            get:
+              summary: Retrieve action details
+              description: Retrieve action details
+              parameters:
+                - in: path
+                  name: name
+                  description: Name of the action
+                  type: string
+              responses:
+                200:
+                  description: Action details to be returned
+                  schema: ActionTriggerDetailsSchema
+                400:
+                  description: Bad request
+            """
             plugin_spec_json = Endpoints.load_file_json_format(
                 "/python/src/plugin.spec.yaml"
             )
@@ -338,51 +356,49 @@ class Endpoints:
         @v1.route("/tasks/<string:name>")
         def task_details(name):
             """Get task details endpoint.
-             ---
-             get:
-               summary: Retrieve task details
-               description: Retrieve task details
-               parameters:
-                 - in: path
-                   name: name
-                   description: Name of the task
-                   type: string
-               responses:
-                 200:
-                   description: Task details to be returned
-                   schema: TaskDetailsSchema
-                 400:
-                   description: Bad request
-             """
+            ---
+            get:
+              summary: Retrieve task details
+              description: Retrieve task details
+              parameters:
+                - in: path
+                  name: name
+                  description: Name of the task
+                  type: string
+              responses:
+                200:
+                  description: Task details to be returned
+                  schema: TaskDetailsSchema
+                400:
+                  description: Bad request
+            """
             plugin_spec_json = Endpoints.load_file_json_format(
                 "/python/src/plugin.spec.yaml"
             )
             Endpoints.action_trigger_task_exists(plugin_spec_json, "tasks", name)
             return jsonify(
-                TaskDetailsSchema().dump(
-                    plugin_spec_json.get("tasks").get(name)
-                )
+                TaskDetailsSchema().dump(plugin_spec_json.get("tasks").get(name))
             )
 
         @v1.route("/triggers/<string:name>")
         def trigger_details(name):
             """Get trigger details endpoint.
-             ---
-             get:
-               summary: Retrieve trigger details
-               description: Retrieve trigger details
-               parameters:
-                 - in: path
-                   name: name
-                   description: Name of the trigger
-                   type: string
-               responses:
-                 200:
-                   description: Trigger details to be returned
-                   schema: ActionTriggerDetailsSchema
-                 400:
-                   description: Bad request
-             """
+            ---
+            get:
+              summary: Retrieve trigger details
+              description: Retrieve trigger details
+              parameters:
+                - in: path
+                  name: name
+                  description: Name of the trigger
+                  type: string
+              responses:
+                200:
+                  description: Trigger details to be returned
+                  schema: ActionTriggerDetailsSchema
+                400:
+                  description: Bad request
+            """
             plugin_spec_json = Endpoints.load_file_json_format(
                 "/python/src/plugin.spec.yaml"
             )
@@ -578,6 +594,20 @@ class Endpoints:
         blueprints = [legacy, v1]
         return blueprints
 
+    def _create_action_definitions_payload(self):
+        """
+        Creates a payload containing definitions for all actions within a given plugin
+        :return: Dictionary containing an actions definitions payload for a plugin
+        """
+
+        payload = {"actionsDefinitions": []}
+        for key, value in self.plugin.actions.items():
+            definition = {"identifier": key, "inputJsonSchema": value.input.schema}
+
+            payload["actionsDefinitions"].append(definition)
+
+        return payload
+
     @staticmethod
     def _number_of_workers():
         """
@@ -647,6 +677,9 @@ class Endpoints:
             output = e.output
             if isinstance(wrapped_exception, ClientException):
                 status_code = 400
+            elif isinstance(wrapped_exception, PluginException):
+                if wrapped_exception.preset is PluginException.Preset.BAD_REQUEST:
+                    status_code = 400
             elif isinstance(wrapped_exception, ServerException):
                 # I'm unsure about this
                 status_code = 500
