@@ -16,6 +16,7 @@ from .exceptions import (
     ServerException,
     LoggedException,
     ConnectionTestException,
+    PluginException,
 )
 from .metrics import MetricsBuilder
 
@@ -409,7 +410,7 @@ class Plugin(object):
                         is_test,
                         is_debug,
                     )
-        except (ClientException, ServerException, Exception) as e:
+        except (ClientException, ServerException, PluginException, Exception) as e:
             success = False
             caught_exception = e
             logger.exception(e)
